@@ -878,15 +878,18 @@ child_watches=%s"""
         /configs/b: no.
         """
         def check_valid(path, print_path):
+            result = "no"
             value, _ = self._zk.get(path)
-            try:
-                x = json.loads(value)
-                result = "yes"
-            except ValueError:
-                result = "no"
+
+            if value is not None:
+                try:
+                    x = json.loads(value)
+                    result = "yes"
+                except ValueError:
+                    pass
 
             if print_path:
-                self.do_output("%s: %s.", path, result)
+                self.do_output("%s: %s.", os.path.basename(path), result)
             else:
                 self.do_output("%s.", result)
 
@@ -933,13 +936,15 @@ child_watches=%s"""
         """
         def json_output(path, print_path):
             value, _ = self._zk.get(path)
-            try:
-                value = json.dumps(json.loads(value), indent=4)
-            except ValueError:
-                pass
+
+            if value is not None:
+                try:
+                    value = json.dumps(json.loads(value), indent=4)
+                except ValueError:
+                    pass
 
             if print_path:
-                self.do_output("%s:\n%s", path, value)
+                self.do_output("%s:\n%s", os.path.basename(path), value)
             else:
                 self.do_output(value)
 
@@ -993,6 +998,10 @@ child_watches=%s"""
 
         def get(path, keys, print_path):
             jstr, _ = self._zk.get(path)
+
+            if jstr is None:
+                raise BadJSON(path)
+
             try:
                 obj = json.loads(jstr)
             except ValueError:
@@ -1001,7 +1010,7 @@ child_watches=%s"""
             value = get_from_obj(obj, keys)
 
             if print_path:
-                self.do_output("%s: %s", path, value)
+                self.do_output("%s: %s", os.path.basename(path), value)
             else:
                 self.do_output(value)
 
